==> genometools-1.0.7.tar.gz: genometools-1.0.7/scripts/skclean.sh <==
#!/bin/sh
#
# Copyright (c) 2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
# Copyright (c) 2007 Center for Bioinformatics, University of Hamburg
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

for filename in `ls src/libgtmatch/*.c`
do
  headfile="obj/src/libgtmatch/`basename ${filename} .c`"
  rm -f ${headfile}.o ${headfile}.d ${headfile}.splint
done

for filename in `ls ${SKTOOLS} src/libgtltr/*.c`
do
  headfile="obj/src/libgtltr/`basename ${filename} .c`"
  rm -f ${headfile}.o ${headfile}.d ${headfile}.splint
done

SKTOOLS=`grep -l Kurtz src/tools/*.c`

for filename in `ls ${SKTOOLS}`
do
  headfile="obj/src/tools/`basename ${filename} .c`"
  rm -f ${headfile}.o ${headfile}.d ${headfile}.splint
done

rm -rf indexdir
rm -f lib/libgtmatch.a
rm -f lib/libgtltr.a
rm -f testsuite/TMP.[a-zA-Z0-9]*
rm -f testsuite/result.mp testsuite/result.vm
rm -f testsuite/sfxidx.esq
rm -f LocalMakefile LocalMakefile.previous

==> genometools-1.2.0.tar.gz: genometools-1.2.0/scripts/skclean.sh <==
#!/bin/sh
#
# Copyright (c) 2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
# Copyright (c) 2007 Center for Bioinformatics, University of Hamburg
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

for filename in `ls src/match/*.c`
do
  headfile="obj/src/match/`basename ${filename} .c`"
  rm -f ${headfile}.o ${headfile}.d ${headfile}.splint
done

for filename in `ls ${SKTOOLS} src/ltr/*.c`
do
  headfile="obj/src/ltr/`basename ${filename} .c`"
  rm -f ${headfile}.o ${headfile}.d ${headfile}.splint
done

SKTOOLS=`grep -l Kurtz src/tools/*.c`

for filename in `ls ${SKTOOLS}`
do
  headfile="obj/src/tools/`basename ${filename} .c`"
  rm -f ${headfile}.o ${headfile}.d ${headfile}.splint
done

rm -rf indexdir
rm -f testsuite/TMP.[a-zA-Z0-9]*
rm -f testsuite/result.mp testsuite/result.vm
rm -f testsuite/sfxidx.esq
rm -f LocalMakefile LocalMakefile.previous
